import React, { useRef, useEffect } from 'react';
import { Button } from '@/components/ui/button';
import { useTheme } from '../contexts/ThemeContext';
import { FiMenu, FiX, FiHelpCircle, FiUsers, FiDollarSign, FiZap, FiExternalLink, FiMoon, FiSun, FiInfo } from 'react-icons/fi';
import { TbMessageChatbot } from "react-icons/tb";
import { LucideCodeXml } from 'lucide-react';
import { Link } from 'react-router-dom';

interface LeftSidebarProps {
  onPromptSelect: (prompt: string, content: any) => void;
  onStartNewChat?: () => void;
}

const suggestedQuestions = [
  { text: "What is MCP?", icon: FiHelpCircle },
  { text: "Who is this for?", icon: FiUsers },
  { text: "Show me how I can earn", icon: FiDollarSign },
  { text: "What can you help me with?", icon: FiZap },
  // { text: "About Us", icon: FiInfo },
  // { text: "Our Team", icon: FiUsers }
];

const navLinks = [
  { text: "Chat", icon: TbMessageChatbot, to: "#" },
  { text: "Home", icon: FiZap, to: "#home" },
  { text: "MCPs", icon: LucideCodeXml, to: "#mcps" },
  { text: "Monetize", icon: FiDollarSign, to: "#monetize" },
  { text: "Team", icon: FiUsers, to: "#team" },
  { text: "About Us", icon: FiInfo, to: "#about" },
];

const LeftSidebar: React.FC<LeftSidebarProps> = ({ onPromptSelect, onStartNewChat }) => {
  const { sidebarOpen, setSidebarOpen } = useTheme();
  const { isDark, toggleTheme } = useTheme();
  const sidebarRef = useRef<HTMLDivElement>(null);

  // Close sidebar on outside click
  useEffect(() => {
    if (!sidebarOpen) return;
    const handleClickOutside = (event: MouseEvent) => {
      if (sidebarRef.current && !sidebarRef.current.contains(event.target as Node)) {
        setSidebarOpen(false);
      }
    };
    document.addEventListener('mousedown', handleClickOutside);
    return () => document.removeEventListener('mousedown', handleClickOutside);
  }, [sidebarOpen, setSidebarOpen]);

  const handlePromptClick = (prompt: string) => {
    const event = new CustomEvent('leftSidebarPrompt', { detail: { prompt } });
    window.dispatchEvent(event);
    onPromptSelect(prompt, null);
    setSidebarOpen(false);
  };

  return (
    <>
      {/* Toggle Button */}
      {!sidebarOpen && (
        <Button
          variant="ghost"
          onClick={() => setSidebarOpen(true)}
          className="fixed top-24 left-4 z-50 w-10 h-10 rounded-xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-md bg-white/80 dark:bg-black/80 hover:bg-white/90 dark:hover:bg-black/90 transition-all duration-300 shadow-lg"
        >
          <FiMenu className="w-4 h-4" />
        </Button>
      )}

      {/* Sidebar */}
      <div
        ref={sidebarRef}
        className={`fixed left-0 top-0 bg-clip-padding backdrop-filter backdrop-blur-sm bg-opacity-10 border-r border-gray-200/20 dark:border-gray-700/20 h-screen w-72 transform transition-transform duration-500 ease-in-out z-40 ${
          sidebarOpen ? 'translate-x-0' : '-translate-x-full'
        }`}
      >
        <div className="h-full flex flex-col bg-white/80 dark:bg-black/80">
          {/* Top Section */}
          <div className="p-6 pb-2 flex items-center justify-between border-b border-gray-200/20 dark:border-gray-700/20">
            <div className="flex items-center gap-2">
              <LucideCodeXml className="w-6 h-6 text-primary" />
              <span className="text-lg font-semibold bg-gradient-to-r from-primary to-purple-600 bg-clip-text text-transparent">FastCode</span>
            </div>
            <Button
              variant="ghost"
              size="sm"
              onClick={toggleTheme}
              className="w-10 h-10 rounded-full border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/10 dark:bg-black/10 hover:bg-white/20 dark:hover:bg-black/20 transition-all duration-300"
              aria-label="Toggle theme"
            >
              {isDark ? <FiSun className="w-4 h-4" /> : <FiMoon className="w-4 h-4" />}
            </Button>
          </div>

          {/* Quick Start Section */}
          <div className="p-6 border-b border-gray-200/20 dark:border-gray-700/20">
            <h3 className="text-xs font-medium text-muted-foreground uppercase tracking-wider mb-4">
              Quick Start
            </h3>
            <div className="space-y-2">
              {suggestedQuestions.map((question, index) => (
                <button
                  key={index}
                  onClick={() => handlePromptClick(question.text)}
                  className="w-full flex items-center p-3 rounded-lg text-left hover:bg-gray-100 dark:hover:bg-gray-800 transition-colors duration-200 group"
                >
                  <question.icon className="w-4 h-4 mr-3 text-muted-foreground group-hover:text-primary transition-colors" />
                  <span className="text-sm font-medium text-foreground">
                    {question.text}
                  </span>
                </button>
              ))}
            </div>
            <Button
              variant="outline"
              className="w-full mt-4"
              onClick={onStartNewChat}
            >
              Start New Chat
            </Button>
          </div>

          {/* Navigation Section */}
          <div className="flex-1 overflow-y-auto p-6">
            <h3 className="text-xs font-medium text-muted-foreground uppercase tracking-wider mb-4">
              Navigation
            </h3>
            <nav className="space-y-1">
              {navLinks.map((link, index) => (
                <a
                  key={index}
                  href={link.to}
                  className="flex items-center p-3 rounded-lg text-left hover:bg-gray-100 dark:hover:bg-gray-800 transition-colors duration-200 group"
                  onClick={() => setSidebarOpen(false)}
                >
                  <link.icon className="w-4 h-4 mr-3 text-muted-foreground group-hover:text-primary transition-colors" />
                  <span className="text-sm font-medium text-foreground">
                    {link.text}
                  </span>
                </a>
              ))}
            </nav>
          </div>

          {/* Bottom Section */}
          <div className="p-6 border-t border-gray-200/20 dark:border-gray-700/20">
            <h3 className="text-xs font-medium text-muted-foreground uppercase tracking-wider mb-4">
              Resources
            </h3>
            <a
              href="https://fastcode.ai"
              target="_blank"
              rel="noopener noreferrer"
              className="flex items-center p-3 rounded-lg hover:bg-gray-100 dark:hover:bg-gray-800 transition-colors duration-200 group"
            >
              <FiExternalLink className="w-4 h-4 mr-3 text-muted-foreground group-hover:text-primary transition-colors" />
              <span className="text-sm font-medium text-foreground">
                Visit Website
              </span>
            </a>
          </div>
        </div>
      </div>
    </>
  );
};

export default LeftSidebar;