import React from 'react';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { Avatar, AvatarFallback, AvatarImage } from '@/components/ui/avatar';
import { Badge } from '@/components/ui/badge';

interface TeamMember {
  name: string;
  role: string;
  avatar?: string;
  description: string;
  socials?: {
    twitter?: string;
    linkedin?: string;
    github?: string;
  };
  tags?: string[];
}

interface TeamSectionProps {
  id?: string;
  className?: string;
}

const TeamSection: React.FC<TeamSectionProps> = ({ id, className = '' }) => {
  const leadership: TeamMember[] = [
    {
      name: 'John Doe',
      role: 'Founder & CEO',
      description: 'Visionary leader with 10+ years of experience in tech startups.',
      tags: ['Leadership', 'Strategy', 'Blockchain'],
      socials: {
        twitter: '#',
        linkedin: '#',
        github: '#'
      }
    },
    {
      name: 'Jane Smith',
      role: 'CTO',
      description: 'Technology expert with a passion for building scalable systems.',
      tags: ['Engineering', 'Architecture', 'AI/ML']
    },
    {
      name: 'Austin Wales',
      role: 'CFO',
      description: 'Finance officer responsible for all the finance related decisions.',
      tags: ['Business', 'Management', 'Finance']
    },
  ];

  const advisors: TeamMember[] = [
    {
      name: 'Dr. Robert Johnson',
      role: 'Blockchain Advisor',
      description: 'Industry veteran with deep expertise in blockchain technology.',
      tags: ['Blockchain', 'Advisor']
    },
    {
      name: 'Sarah Williams',
      role: 'AI Research Advisor',
      description: 'Leading researcher in artificial intelligence and machine learning.',
      tags: ['AI/ML', 'Research']
    },
  ];

  const interns: TeamMember[] = [
    {
      name: 'Alex Chen',
      role: 'Software Engineering Intern',
      description: 'Computer Science student passionate about decentralized technologies.',
      tags: ['Intern', 'Developer']
    },
    {
      name: 'Maria Garcia',
      role: 'UI/UX Design Intern',
      description: 'Design student focused on creating intuitive user experiences.',
      tags: ['Intern', 'Design']
    },
  ];

  const renderTeamMember = (member: TeamMember, index: number) => (
    <Card key={index} className="h-full flex flex-col hover:shadow-lg transition-shadow">
      <CardHeader className="flex flex-col items-center text-center pb-2">
        <Avatar className="h-24 w-24 mb-4 border-2 border-primary/20">
          <AvatarImage src={member.avatar} alt={member.name} />
          <AvatarFallback className="bg-primary/10 text-primary">
            {member.name.split(' ').map(n => n[0]).join('')}
          </AvatarFallback>
        </Avatar>
        <CardTitle className="text-xl">{member.name}</CardTitle>
        <p className="text-primary font-medium">{member.role}</p>
      </CardHeader>
      <CardContent className="flex-1 flex flex-col items-center text-center px-4 pb-4">
        <p className="text-sm text-muted-foreground mb-4">{member.description}</p>
        <div className="flex flex-wrap justify-center gap-2 mt-auto">
          {member.tags?.map((tag, i) => (
            <Badge key={i} variant="outline" className="text-xs">
              {tag}
            </Badge>
          ))}
        </div>
      </CardContent>
    </Card>
  );

  const renderTeamSection = (title: string, members: TeamMember[]) => (
    <div className="mb-12">
      <h3 className="text-2xl mb-6 text-center">{title}</h3>
      <div className="grid gap-6 mx-auto px-auto max-w-7xl grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 justify-center">
        {members.map((member, index) => renderTeamMember(member, index))}
      </div>
    </div>
  );

  return (
    <section id={id} className={`py-16 md:py-24 ${className}`}>
      <div className="container mx-auto px-4">
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl mb-4">Our Team</h2>
          <p className="text-xl text-muted-foreground max-w-3xl mx-auto">
            Meet the talented individuals behind our success
          </p>
        </div>

        {renderTeamSection('Leadership', leadership)}
        {advisors.length > 0 && renderTeamSection('Advisors', advisors)}
        {interns.length > 0 && renderTeamSection('Interns', interns)}
      </div>
    </section>
  );
};

export default TeamSection;